@@ -21,7 +21,7 @@ except:
     info("github-tools' task not available")
 
 
-version='0.1.6'
+version='0.1.7'
 
 long_description = open('README.rst', 'r').read()
 
@@ -30,7 +30,6 @@ classifiers = [
     "Programming Language :: Python :: 2.5", # not yet tested on python 2.6
     "Development Status :: 4 - Beta",
     "Environment :: Console",
-    "Framework :: Paste",
     "Intended Audience :: Developers",
     "License :: OSI Approved :: BSD License",
     "Operating System :: POSIX :: Linux", # Not tested yet on osx or Windows
@@ -130,8 +129,8 @@ if 'gh_pages_build' in globals():
     
     @task
     def adjust_options():
-        options.gh_pages_update.setdefault(
-            'commit_message', 'Update doc to %s' % version)
+        options.update(
+            gh_pages_update=Bunch(commit_message='Update doc to %s' % version))
     
     @task
     @needs('sdist', 'tag', 'setuptools.command.upload',
